@@ -21,8 +21,8 @@
 
 #include "capture.h"
 
-#include <QtGui/QApplication>
-#include <QtCore/QUrl>
+#include <QApplication>
+#include <QUrl>
 
 int main(int argc, char** argv)
 {
