@@ -42,26 +42,26 @@
 #ifndef VOLUMESLIDER_PLUGIN_H
 #define VOLUMESLIDER_PLUGIN_H
 
-#include <QtDesigner/QDesignerCustomWidgetInterface>
+#include <QDesignerCustomWidgetInterface>
 
 class VolumeSliderPlugin: public QObject, public QDesignerCustomWidgetInterface
 {
     Q_OBJECT
     Q_INTERFACES(QDesignerCustomWidgetInterface)
 public:
-    explicit VolumeSliderPlugin(const QString &group, QObject *parent = 0);
+    explicit VolumeSliderPlugin(const QString &group, QObject *parent = nullptr);
 
-    virtual QString name() const;
-    virtual QString group() const;
-    virtual QString toolTip() const;
-    virtual QString whatsThis() const;
-    virtual QString includeFile() const;
-    virtual QIcon icon() const;
-    virtual bool isContainer() const;
-    virtual QWidget *createWidget(QWidget *parent);
-    virtual bool isInitialized() const;
-    virtual void initialize(QDesignerFormEditorInterface *core);
-    virtual QString domXml() const;
+    QString name() const override;
+    QString group() const override;
+    QString toolTip() const override;
+    QString whatsThis() const override;
+    QString includeFile() const override;
+    QIcon icon() const override;
+    bool isContainer() const override;
+    QWidget *createWidget(QWidget *parent) override;
+    bool isInitialized() const override;
+    void initialize(QDesignerFormEditorInterface *core) override;
+    QString domXml() const override;
 
 private:
     const QString m_group;
