@@ -43,15 +43,15 @@ class PHONON_EXPORT AbstractMediaStreamPrivate : private MediaNodeDestructionHan
     public:
         void setStreamInterface(StreamInterface *);
         void setMediaObjectPrivate(MediaObjectPrivate *);
-        ~AbstractMediaStreamPrivate();
+        ~AbstractMediaStreamPrivate() override;
 
     protected:
         AbstractMediaStreamPrivate()
             : streamSize(0),
             streamSeekable(false),
             ignoreWrites(false),
-            streamInterface(0),
-            mediaObjectPrivate(0),
+            streamInterface(nullptr),
+            mediaObjectPrivate(nullptr),
             errorType(NoError)
         {
         }
