@@ -26,8 +26,8 @@
 #include "phonon_export.h"
 #include "objectdescription.h"
 
-#include <QtCore/QObject>
-
+#include <QObject>
+#include <QStringList>
 
 #ifdef __QT_SYNCQT__
 // Tell syncqt that the BackendCapabilities namespace should be treated like a class
@@ -36,7 +36,6 @@
 #endif
 
 template<class T> class QList;
-class QStringList;
 
 namespace Phonon
 {
