@@ -26,8 +26,8 @@
 #include "effect.h"
 #include "effectparameter.h"
 #include "medianode_p.h"
-#include <QtCore/QHash>
-#include <QtCore/QVariant>
+#include <QHash>
+#include <QVariant>
 #include "phonondefs_p.h"
 
 #ifndef QT_NO_PHONON_EFFECT
@@ -39,7 +39,7 @@ class EffectPrivate : public MediaNodePrivate
     P_DECLARE_PUBLIC(Effect)
     PHONON_PRIVATECLASS
     public:
-        virtual QObject *qObject() override { return q_func(); }
+        QObject *qObject() override { return q_func(); }
     protected:
         EffectPrivate()
         {
