@@ -22,7 +22,7 @@
 #include "videodataoutput.h"
 #include "videodataoutput_p.h"
 #include "factory_p.h"
-#include <QtCore/QSize>
+#include <QSize>
 #include "videoframe2.h"
 
 #define PHONON_CLASSNAME VideoDataOutput
