@@ -22,7 +22,7 @@
 #ifndef PHONON_GLOBALSTATIC_P_H
 #define PHONON_GLOBALSTATIC_P_H
 
-#include <QtCore/QAtomicPointer>
+#include <QAtomicPointer>
 
 //
 // WARNING!!
@@ -73,7 +73,7 @@ class CleanUpGlobalStatic
 #endif
 
 /**
- * This macro makes it easy to use non-POD types as global statics.
+ * This macro makes it easy to use non-POD types as global statistics.
  * The object is created on first use and creation is threadsafe.
  *
  * The object is destructed on library unload or application exit.
@@ -87,7 +87,7 @@ class CleanUpGlobalStatic
  * for that using the isDestroyed() function.
  *
  * If needed (If the destructor of the global object calls other functions that depend on other
- * global statics (e.g. KConfig::sync) your destructor has to be called before those global statics
+ * global statistics (e.g. KConfig::sync) your destructor has to be called before those global statistics
  * are destroyed. A Qt post routine does that.) you can also install a post routine (@ref qAddPostRoutine) to clean up the object
  * using the destroy() method. If you registered a post routine and the object is destroyed because
  * of a lib unload you have to call qRemovePostRoutine!
@@ -244,7 +244,7 @@ class CleanUpGlobalStatic
  * @ingroup KDEMacros
  */
     #define PHONON_GLOBAL_STATIC_WITH_ARGS(TYPE, NAME, ARGS)                            \
-    static QBasicAtomicPointer<TYPE > _k_static_##NAME = Q_BASIC_ATOMIC_INITIALIZER(0); \
+    static QBasicAtomicPointer<TYPE > _k_static_##NAME = Q_BASIC_ATOMIC_INITIALIZER(nullptr); \
     static bool _k_static_##NAME##_destroyed;                                           \
     static struct PHONON_GLOBAL_STATIC_STRUCT_NAME(NAME)                                \
     {                                                                                   \
@@ -254,7 +254,7 @@ class CleanUpGlobalStatic
         }                                                                               \
         inline bool exists() const                                                      \
         {                                                                               \
-            return _k_static_##NAME.load() != 0;                                        \
+            return _k_static_##NAME.loadRelaxed() != nullptr;                           \
         }                                                                               \
         inline operator TYPE*()                                                         \
         {                                                                               \
@@ -262,20 +262,20 @@ class CleanUpGlobalStatic
         }                                                                               \
         inline TYPE *operator->()                                                       \
         {                                                                               \
-            if (!_k_static_##NAME.load()) {                                             \
+            if (!_k_static_##NAME.loadRelaxed()) {                                      \
                 if (isDestroyed()) {                                                    \
                     qFatal("Fatal Error: Accessed global static '%s *%s()' after destruction. " \
                           "Defined at %s:%d", #TYPE, #NAME, __FILE__, __LINE__);       \
                 }                                                                       \
                 TYPE *x = new TYPE ARGS;                                                \
-                if (!_k_static_##NAME.testAndSetOrdered(0, x)                           \
-                    && _k_static_##NAME.load() != x ) {                                 \
+                if (!_k_static_##NAME.testAndSetOrdered(nullptr, x)                     \
+                    && _k_static_##NAME.loadRelaxed() != x ) {                          \
                     delete x;                                                           \
                 } else {                                                                \
                     static Phonon::CleanUpGlobalStatic cleanUpObject = { destroy };     \
                 }                                                                       \
             }                                                                           \
-            return _k_static_##NAME.load();                                             \
+            return _k_static_##NAME.loadRelaxed();                                      \
         }                                                                               \
         inline TYPE &operator*()                                                        \
         {                                                                               \
@@ -284,8 +284,8 @@ class CleanUpGlobalStatic
         static void destroy()                                                           \
         {                                                                               \
             _k_static_##NAME##_destroyed = true;                                        \
-            TYPE *x = _k_static_##NAME.load();                                          \
-            _k_static_##NAME.store(0);                                                  \
+            TYPE *x = _k_static_##NAME.loadRelaxed();                                   \
+            _k_static_##NAME.storeRelaxed(nullptr);                                     \
             delete x;                                                                   \
         }                                                                               \
     } NAME;
