@@ -39,8 +39,8 @@ class IODeviceStream : public AbstractMediaStream
     Q_OBJECT
     Q_DECLARE_PRIVATE(IODeviceStream)
     public:
-        explicit IODeviceStream(QIODevice *ioDevice, QObject *parent = 0);
-        ~IODeviceStream();
+        explicit IODeviceStream(QIODevice *ioDevice, QObject *parent = nullptr);
+        ~IODeviceStream() override;
 
         void reset() override;
         void needData() override;
