@@ -25,10 +25,10 @@
 #include "mediacontroller.h"
 #include "mediaobject.h"
 #include "addoninterface.h"
-#include <QtCore/QList>
-#include <QtCore/QVariant>
-#include <QtCore/QTextCodec>
-#include <QtGui/QFont>
+#include <QList>
+#include <QVariant>
+#include <QTextCodec>
+#include <QFont>
 #include "frontendinterface_p.h"
 
 #ifndef QT_NO_PHONON_MEDIACONTROLLER
@@ -41,7 +41,7 @@ class MediaControllerPrivate : public FrontendInterfacePrivate
     public:
         MediaControllerPrivate(MediaObject *mp) : FrontendInterfacePrivate(mp) {}
 
-        virtual void backendObjectChanged(QObject *) override;
+        void backendObjectChanged(QObject *) override;
         MediaController *q;
 };
 
@@ -317,14 +317,14 @@ void MediaController::setCurrentAudioChannel(const Phonon::AudioChannelDescripti
 {
     IFACE;
     iface->interfaceCall(AddonInterface::AudioChannelInterface,
-        AddonInterface::setCurrentAudioChannel, QList<QVariant>() << qVariantFromValue(stream));
+        AddonInterface::setCurrentAudioChannel, QList<QVariant>() << QVariant::fromValue(stream));
 }
 
 void MediaController::setCurrentSubtitle(const Phonon::SubtitleDescription &stream)
 {
     IFACE;
     iface->interfaceCall(AddonInterface::SubtitleInterface,
-        AddonInterface::setCurrentSubtitle, QList<QVariant>() << qVariantFromValue(stream));
+        AddonInterface::setCurrentSubtitle, QList<QVariant>() << QVariant::fromValue(stream));
 }
 
 void MediaController::setCurrentSubtitle(const QUrl &url)
