@@ -23,10 +23,10 @@
 #include "objectdescription.h"
 #include "objectdescription_p.h"
 
-#include <QtCore/QObject>
-#include <QtCore/QSet>
+#include <QObject>
+#include <QSet>
+#include <QStringList>
 #include "factory_p.h"
-#include <QtCore/QStringList>
 #include "backendinterface.h"
 #include "platformplugin.h"
 #include "pulsesupport.h"
@@ -102,7 +102,7 @@ QList<QByteArray> ObjectDescriptionData::propertyNames() const
 
 bool ObjectDescriptionData::isValid() const
 {
-    return d != 0;
+    return d != nullptr;
 }
 
 ObjectDescriptionData *ObjectDescriptionData::fromIndex(ObjectDescriptionType type, int index)
@@ -110,7 +110,7 @@ ObjectDescriptionData *ObjectDescriptionData::fromIndex(ObjectDescriptionType ty
     bool is_audio_device = (AudioOutputDeviceType == type || AudioCaptureDeviceType == type);
 
     PulseSupport *pulse = PulseSupport::getInstance();
-    if (is_audio_device && pulse->isActive()) {
+    if (is_audio_device && pulse->isUsed()) {
         QList<int> indexes = pulse->objectDescriptionIndexes(type);
         if (indexes.contains(index)) {
             QHash<QByteArray, QVariant> properties = pulse->objectDescriptionProperties(type, index);
@@ -119,7 +119,7 @@ ObjectDescriptionData *ObjectDescriptionData::fromIndex(ObjectDescriptionType ty
 
         // When Pulse is enabled, only try from the platform plugin or backend if it is about audio capture
         if (type != AudioCaptureDeviceType)
-            return new ObjectDescriptionData(0); // invalid
+            return new ObjectDescriptionData(nullptr); // invalid
     }
 
 #ifndef QT_NO_PHONON_PLATFORMPLUGIN
@@ -143,15 +143,17 @@ ObjectDescriptionData *ObjectDescriptionData::fromIndex(ObjectDescriptionType ty
         }
     }
 
-    return new ObjectDescriptionData(0); // invalid
+    return new ObjectDescriptionData(nullptr); // invalid
 }
 
 } //namespace Phonon
 
 
+#if QT_VERSION < QT_VERSION_CHECK(6, 0, 0)
 void Phonon::registerMetaTypes()
 {
     // Deprecated, does nothing
 }
+#endif
 
 // vim: sw=4 ts=4
