@@ -24,14 +24,14 @@
 #include "objectdescriptionmodel_p.h"
 #include "phonondefs_p.h"
 #include "platform_p.h"
-#include <QtCore/QList>
 #include "objectdescription.h"
 #include "phononnamespace_p.h"
-#include <QtCore/QMimeData>
-#include <QtCore/QStringList>
+#include "factory_p.h"
 #include <QIcon>
 #include <QPainter>
-#include "factory_p.h"
+#include <QList>
+#include <QMimeData>
+#include <QStringList>
 
 #ifndef QT_NO_PHONON_OBJECTDESCRIPTIONMODEL
 
@@ -55,6 +55,7 @@ static const uint qt_meta_data_Phonon__ObjectDescriptionModel[] = {
        0        // eod
 };
 
+#if QT_VERSION < QT_VERSION_CHECK(6, 0, 0)
     #define P_STATIC_META_STRINGDATA(name, string, stringlen, stringlenplustwo) \
         struct qt_meta_stringdata_Phonon__ObjectDescriptionModel_##name##_t { QByteArrayData data[1]; char stringdata[stringlenplustwo]; }; \
         static const qt_meta_stringdata_Phonon__ObjectDescriptionModel_##name##_t qt_meta_stringdata_Phonon__ObjectDescriptionModel_##name = { \
@@ -63,6 +64,16 @@ static const uint qt_meta_data_Phonon__ObjectDescriptionModel[] = {
             }, \
             string \
         };
+#else
+    #define P_STATIC_META_STRINGDATA(name, string, stringlen, stringlenplustwo) \
+        struct qt_meta_stringdata_Phonon__ObjectDescriptionModel_##name##_t { const uint offsetsAndSize[2]; char stringdata[stringlenplustwo]; }; \
+        static const qt_meta_stringdata_Phonon__ObjectDescriptionModel_##name##_t qt_meta_stringdata_Phonon__ObjectDescriptionModel_##name = { \
+            { \
+                uint(offsetof(qt_meta_stringdata_Phonon__ObjectDescriptionModel_ ## name ## _t, stringdata)), stringlen \
+            }, \
+            string \
+        };
+#endif
 
     P_STATIC_META_STRINGDATA(AudioOutputDeviceType,     "Phonon::AudioOutputDeviceModel\0",  30, 32)
     P_STATIC_META_STRINGDATA(AudioCaptureDeviceType,    "Phonon::AudioCaptureDeviceModel\0", 31, 33)
@@ -73,11 +84,19 @@ static const uint qt_meta_data_Phonon__ObjectDescriptionModel[] = {
 
     #undef P_STATIC_META_STRINGDATA
 
+#if QT_VERSION < QT_VERSION_CHECK(6, 0, 0)
     #define OBJECT_DESCRIPTION_MODEL_STATIC_META_OBJECT(X) { \
         &QAbstractListModel::staticMetaObject, \
         qt_meta_stringdata_Phonon__ObjectDescriptionModel_##X.data, \
         qt_meta_data_Phonon__ObjectDescriptionModel, \
-        0, 0, 0 }
+        nullptr, nullptr, nullptr }
+#else
+    #define OBJECT_DESCRIPTION_MODEL_STATIC_META_OBJECT(X) { \
+        &QAbstractListModel::staticMetaObject, \
+        qt_meta_stringdata_Phonon__ObjectDescriptionModel_##X.offsetsAndSize, \
+        qt_meta_data_Phonon__ObjectDescriptionModel, \
+        nullptr, nullptr, nullptr }
+#endif
 
 namespace Phonon
 {
@@ -112,7 +131,7 @@ void *ObjectDescriptionModel<type>::qt_metacast(const char *_clname)
 {
     qWarning("WARNING: Phonon4Qt5 has not been verified to successfully qt_metacast ObjectDescriptionModels.");
     if (!_clname) {
-        return 0;
+        return nullptr;
     }
     if (!strcmp(_clname, ObjectDescriptionModel<type>::staticMetaObject.className())) {
         return static_cast<void *>(const_cast<ObjectDescriptionModel<type> *>(this));
@@ -234,7 +253,11 @@ void ObjectDescriptionModelData::moveUp(const QModelIndex &index)
 
     emit d->model->layoutAboutToBeChanged();
     QModelIndex above = index.sibling(index.row() - 1, index.column());
+#if QT_VERSION >= QT_VERSION_CHECK(5, 13, 0)
+    d->data.swapItemsAt(index.row(), above.row());
+#else
     d->data.swap(index.row(), above.row());
+#endif
     QModelIndexList from, to;
     from << index << above;
     to << above << index;
@@ -249,7 +272,11 @@ void ObjectDescriptionModelData::moveDown(const QModelIndex &index)
 
     emit d->model->layoutAboutToBeChanged();
     QModelIndex below = index.sibling(index.row() + 1, index.column());
+#if QT_VERSION >= QT_VERSION_CHECK(5, 13, 0)
+    d->data.swapItemsAt(index.row(), below.row());
+#else
     d->data.swap(index.row(), below.row());
+#endif
     QModelIndexList from, to;
     from << index << below;
     to << below << index;
@@ -282,7 +309,7 @@ QList<QExplicitlySharedDataPointer<ObjectDescriptionData> > ObjectDescriptionMod
 QExplicitlySharedDataPointer<ObjectDescriptionData> ObjectDescriptionModelData::modelData(const QModelIndex &index) const
 {
     if (!index.isValid() || index.row() >= d->data.size() || index.column() != 0) {
-        return QExplicitlySharedDataPointer<ObjectDescriptionData>(new ObjectDescriptionData(0));
+        return QExplicitlySharedDataPointer<ObjectDescriptionData>(new ObjectDescriptionData(nullptr));
     }
     return d->data.at(index.row());
 }
