@@ -24,9 +24,9 @@
 #define PATH_P_H
 
 #include "path.h"
-#include <QtCore/QPair>
-#include <QtCore/QList>
-#include <QtCore/QSharedData>
+#include <QPair>
+#include <QList>
+#include <QSharedData>
 #include "effect.h"
 #include "medianodedestructionhandler_p.h"
 
@@ -44,14 +44,14 @@ class PathPrivate : public QSharedData, private MediaNodeDestructionHandler
     friend class Path;
     public:
         PathPrivate()
-            : sourceNode(0), sinkNode(0)
+            : sourceNode(nullptr), sinkNode(nullptr)
 #ifndef QT_NO_PHONON_EFFECT
-            , effectsParent(0)
+            , effectsParent(nullptr)
 #endif //QT_NO_PHONON_EFFECT
         {
         }
 
-        ~PathPrivate();
+        ~PathPrivate() override;
 
         MediaNode *sourceNode;
         MediaNode *sinkNode;
