@@ -24,9 +24,9 @@
 #define PHONON_PLATFORM_P_H
 
 
-#include <QtCore/QStringList>
-#include <QtCore/QtGlobal>
-#include <QtCore/QPair>
+#include <QStringList>
+#include <QtGlobal>
+#include <QPair>
 #include "phonon_export.h"
 #include "objectdescription.h"
 
@@ -45,10 +45,10 @@ namespace Platform
 void saveVolume(const QString &outputName, qreal volume);
 qreal loadVolume(const QString &outputName);
 AbstractMediaStream *createMediaStream(const QUrl &url, QObject *parent);
-QIcon icon(const QString &name, QStyle *style = 0);
+QIcon icon(const QString &name, QStyle *style = nullptr);
 void notification(const char *notificationName, const QString &text,
-        const QStringList &actions = QStringList(), QObject *receiver = 0,
-        const char *actionSlot = 0);
+        const QStringList &actions = QStringList(), QObject *receiver = nullptr,
+        const char *actionSlot = nullptr);
 QString applicationName();
 QList<QPair<QByteArray, QString> > deviceAccessListFor(const Phonon::AudioOutputDevice &deviceDesc);
 
