@@ -23,7 +23,7 @@
 #ifndef PHONON_PULSESTREAM_P_H
 #define PHONON_PULSESTREAM_P_H
 
-#include <QtCore/QObject>
+#include <QObject>
 
 #include <pulse/pulseaudio.h>
 #include <stdint.h>
@@ -39,7 +39,7 @@ namespace Phonon
         Q_OBJECT
         public:
             PulseStream(QString streamUuid, QString role);
-            ~PulseStream();
+            ~PulseStream() override;
 
             QString uuid() const;
 
