@@ -51,7 +51,7 @@ namespace Phonon
 {
 
 QMutex probeMutex;
-static PulseSupport *s_instance = NULL;
+static PulseSupport *s_instance = nullptr;
 static bool s_wasShutDown = false;
 static bool s_pulseActive = false;
 
@@ -75,7 +75,7 @@ static int debugLevel() {
     return level;
 }
 
-static void logMessage(const QString &message, int priority = 2, QObject *obj=0);
+static void logMessage(const QString &message, int priority = 2, QObject *obj=nullptr);
 static void logMessage(const QString &message, int priority, QObject *obj)
 {
     if (debugLevel() > 0) {
@@ -85,7 +85,7 @@ static void logMessage(const QString &message, int priority, QObject *obj)
             QByteArray className(obj->metaObject()->className());
             int nameLength = className.length() - className.lastIndexOf(':') - 1;
             className = className.right(nameLength);
-            output.sprintf("%s %s (%s %p)", message.toLatin1().constData(),
+            output.asprintf("%s %s (%s %p)", message.toLatin1().constData(),
                            obj->objectName().toLatin1().constData(),
                            className.constData(), obj);
         }
@@ -144,8 +144,8 @@ class PulseUserData
         QMap<Phonon::CaptureCategory, QMap<int, int> > newCaptureDevicePriorities; // prio, device
 };
 
-static pa_glib_mainloop *s_mainloop = NULL;
-static pa_context *s_context = NULL;
+static pa_glib_mainloop *s_mainloop = nullptr;
+static pa_context *s_context = nullptr;
 
 
 
@@ -176,7 +176,7 @@ static PulseStream* findStreamByPulseIndex(QMap<QString, PulseStream*> map, uint
   for (it = map.begin(); it != map.end(); ++it)
     if ((*it)->index() == index)
       return *it;
-  return NULL;
+  return nullptr;
 }
 
 static Phonon::Category pulseRoleToPhononCategory(const char *role, bool *success)
@@ -301,7 +301,7 @@ static void ext_device_manager_read_cb(pa_context *c, const pa_ext_device_manage
         logMessage(QString::fromLatin1("Failed to initialize device manager extension: %1").arg(pa_strerror(pa_context_errno(c))));
         if (s_context != c) {
             logMessage(QLatin1String("Falling back to single device mode"));
-            // Only create our gerneric devices during the probe phase.
+            // Only create our generic devices during the probe phase.
             createGenericDevices();
             // As this is our probe phase, exit immediately
             pa_context_disconnect(c);
@@ -396,8 +396,8 @@ static void ext_device_manager_read_cb(pa_context *c, const pa_ext_device_manage
         }
 
         if (s_instance) {
-            // This wont be emitted during the connection probe phase
-            // which is intensional
+            // This won't be emitted during the connection probe phase
+            // which is intentional
             if (output_changed)
                 s_instance->emitObjectDescriptionChanged(AudioOutputDeviceType);
             if (capture_changed)
@@ -450,9 +450,9 @@ static void ext_device_manager_read_cb(pa_context *c, const pa_ext_device_manage
     // QString wrapper
     QString name(info->name);
     int index;
-    QMap<Phonon::Category, QMap<int, int> > *new_prio_map_cats = NULL; // prio, device
-    QMap<Phonon::CaptureCategory, QMap<int, int> > *new_prio_map_capcats = NULL; // prio, device
-    QMap<QString, AudioDevice> *new_devices = NULL;
+    QMap<Phonon::Category, QMap<int, int> > *new_prio_map_cats = nullptr; // prio, device
+    QMap<Phonon::CaptureCategory, QMap<int, int> > *new_prio_map_capcats = nullptr; // prio, device
+    QMap<QString, AudioDevice> *new_devices = nullptr;
 
     bool isSink = false;
     bool isSource = false;
@@ -548,7 +548,7 @@ static void sink_input_cb(pa_context *c, const pa_sink_input_info *i, int eol, v
     if ((t = pa_proplist_gets(i->proplist, PA_PROP_PHONON_STREAMID))) {
         logMessage(QString::fromLatin1("Found PulseAudio stream index %1 for Phonon Output Stream %2").arg(i->index).arg(QLatin1String(t)));
 
-        // We only care about our own streams (other phonon processes are irrelevent)
+        // We only care about our own streams (other phonon processes are irrelevant)
         if (s_outputStreams.contains(QLatin1String(t))) {
             PulseStream *stream = s_outputStreams[QString(t)];
             stream->setIndex(i->index);
@@ -591,7 +591,7 @@ static void source_output_cb(pa_context *c, const pa_source_output_info *i, int
     if ((t = pa_proplist_gets(i->proplist, PA_PROP_PHONON_STREAMID))) {
         logMessage(QString::fromLatin1("Found PulseAudio stream index %1 for Phonon Capture Stream %2").arg(i->index).arg(QLatin1String(t)));
 
-        // We only care about our own streams (other phonon processes are irrelevent)
+        // We only care about our own streams (other phonon processes are irrelevant)
         if (s_captureStreams.contains(QLatin1String(t))) {
             PulseStream *stream = s_captureStreams[QString(t)];
             stream->setIndex(i->index);
@@ -625,7 +625,7 @@ static void subscribe_cb(pa_context *c, pa_subscription_event_type_t t, uint32_t
                 }
             } else {
                 pa_operation *o;
-                if (!(o = pa_context_get_sink_input_info(c, index, sink_input_cb, NULL))) {
+                if (!(o = pa_context_get_sink_input_info(c, index, sink_input_cb, nullptr))) {
                     logMessage(QString::fromLatin1("pa_context_get_sink_input_info() failed"));
                     return;
                 }
@@ -642,7 +642,7 @@ static void subscribe_cb(pa_context *c, pa_subscription_event_type_t t, uint32_t
                 }
             } else {
                 pa_operation *o;
-                if (!(o = pa_context_get_source_output_info(c, index, source_output_cb, NULL))) {
+                if (!(o = pa_context_get_source_output_info(c, index, source_output_cb, nullptr))) {
                     logMessage(QString::fromLatin1("pa_context_get_sink_input_info() failed"));
                     return;
                 }
@@ -684,11 +684,11 @@ static void context_state_callback(pa_context *c, void *)
 
         // 1. Register for the stream changes (except during probe)
         if (s_context == c) {
-            pa_context_set_subscribe_callback(c, subscribe_cb, NULL);
+            pa_context_set_subscribe_callback(c, subscribe_cb, nullptr);
 
             if (!(o = pa_context_subscribe(c, (pa_subscription_mask_t)
                                               (PA_SUBSCRIPTION_MASK_SINK_INPUT|
-                                               PA_SUBSCRIPTION_MASK_SOURCE_OUTPUT), NULL, NULL))) {
+                                               PA_SUBSCRIPTION_MASK_SOURCE_OUTPUT), nullptr, nullptr))) {
                 logMessage(QLatin1String("pa_context_subscribe() failed"));
                 return;
             }
@@ -702,7 +702,7 @@ static void context_state_callback(pa_context *c, void *)
               logMessage(QString::fromLatin1("Phonon Output Stream %1 is gone at the PA end. Marking it as invalid in our cache as we may reuse it.").arg(stream->uuid()));
               stream->setIndex(PA_INVALID_INDEX);
             }
-            if (!(o = pa_context_get_sink_input_info_list(c, sink_input_cb, NULL))) {
+            if (!(o = pa_context_get_sink_input_info_list(c, sink_input_cb, nullptr))) {
               logMessage(QString::fromLatin1("pa_context_get_sink_input_info_list() failed"));
               return;
             }
@@ -713,7 +713,7 @@ static void context_state_callback(pa_context *c, void *)
               logMessage(QString::fromLatin1("Phonon Capture Stream %1 is gone at the PA end. Marking it as invalid in our cache as we may reuse it.").arg(stream->uuid()));
               stream->setIndex(PA_INVALID_INDEX);
             }
-            if (!(o = pa_context_get_source_output_info_list(c, source_output_cb, NULL))) {
+            if (!(o = pa_context_get_source_output_info_list(c, source_output_cb, nullptr))) {
               logMessage(QString::fromLatin1("pa_context_get_source_output_info_list() failed"));
               return;
             }
@@ -723,8 +723,8 @@ static void context_state_callback(pa_context *c, void *)
 #if HAVE_PULSEAUDIO_DEVICE_MANAGER
         // 2a. Attempt to initialise Device Manager info (except during probe)
         if (s_context == c) {
-            pa_ext_device_manager_set_subscribe_cb(c, ext_device_manager_subscribe_cb, NULL);
-            if (!(o = pa_ext_device_manager_subscribe(c, 1, NULL, NULL))) {
+            pa_ext_device_manager_set_subscribe_cb(c, ext_device_manager_subscribe_cb, nullptr);
+            if (!(o = pa_ext_device_manager_subscribe(c, 1, nullptr, nullptr))) {
                 logMessage(QString::fromLatin1("pa_ext_device_manager_subscribe() failed"));
                 return;
             }
@@ -736,7 +736,7 @@ static void context_state_callback(pa_context *c, void *)
         if (!(o = pa_ext_device_manager_read(c, ext_device_manager_read_cb, u))) {
             if (s_context != c) {
                 logMessage(QString::fromLatin1("pa_ext_device_manager_read() failed. Attempting to continue without device manager support"));
-                // Only create our gerneric devices during the probe phase.
+                // Only create our generic devices during the probe phase.
                 createGenericDevices();
                 // As this is our probe phase, exit immediately
                 pa_context_disconnect(c);
@@ -750,7 +750,7 @@ static void context_state_callback(pa_context *c, void *)
 #else
         // If we know do not have Device Manager support, we just create our dummy devices now
         if (s_context != c) {
-            // Only create our gerneric devices during the probe phase.
+            // Only create our generic devices during the probe phase.
             createGenericDevices();
             // As this is our probe phase, exit immediately
             pa_context_disconnect(c);
@@ -766,7 +766,7 @@ static void context_state_callback(pa_context *c, void *)
             pa_context_disconnect(c);
         else {
             pa_context_unref(s_context);
-            s_context = NULL;
+            s_context = nullptr;
             QTimer::singleShot(50, PulseSupport::getInstance(), SLOT(connectToDaemon()));
         }
     }
@@ -776,18 +776,18 @@ static void context_state_callback(pa_context *c, void *)
 PulseSupport *PulseSupport::getInstanceOrNull(bool allowNull)
 {
     if (s_wasShutDown && allowNull) {
-        return NULL;
+        return nullptr;
     }
 
-    if (NULL == s_instance) {
+    if (nullptr == s_instance) {
         /*
          * In order to prevent the instance being used from multiple threads
-         * prior to it being contructed fully, we need to ensure we obtain a
+         * prior to it being constructed fully, we need to ensure we obtain a
          * lock prior to creating it. After we acquire the lock, check to see
          * if the object is created again before proceeding.
          */
         probeMutex.lock();
-        if (NULL == s_instance)
+        if (nullptr == s_instance)
             s_instance = new PulseSupport();
         probeMutex.unlock();
     }
@@ -801,9 +801,9 @@ PulseSupport *PulseSupport::getInstance()
 
 void PulseSupport::shutdown()
 {
-    if (NULL != s_instance) {
+    if (nullptr != s_instance) {
         delete s_instance;
-        s_instance = NULL;
+        s_instance = nullptr;
         s_wasShutDown = true;
     }
 }
@@ -846,7 +846,7 @@ PulseSupport::PulseSupport()
         return;
     }
 
-    // First of all conenct to PA via simple/blocking means and if that succeeds,
+    // First of all connect to PA via simple/blocking means and if that succeeds,
     // use a fully async integrated mainloop method to connect and get proper support.
     pa_mainloop *p_test_mainloop;
     if (!(p_test_mainloop = pa_mainloop_new())) {
@@ -863,7 +863,7 @@ PulseSupport::PulseSupport()
 
     logMessage(QLatin1String("Probing for PulseAudio..."));
     // (cg) Convert to PA_CONTEXT_NOFLAGS when PulseAudio 0.9.19 is required
-    if (pa_context_connect(p_test_context, NULL, static_cast<pa_context_flags_t>(0), NULL) < 0) {
+    if (pa_context_connect(p_test_context, nullptr, static_cast<pa_context_flags_t>(0), nullptr) < 0) {
         logMessage(QString::fromLatin1("PulseAudio support disabled: %1").arg(QString::fromLocal8Bit(pa_strerror(pa_context_errno(p_test_context)))));
         pa_context_disconnect(p_test_context);
         pa_context_unref(p_test_context);
@@ -871,9 +871,9 @@ PulseSupport::PulseSupport()
         return;
     }
 
-    pa_context_set_state_callback(p_test_context, &context_state_callback, NULL);
+    pa_context_set_state_callback(p_test_context, &context_state_callback, nullptr);
     for (;;) {
-        pa_mainloop_iterate(p_test_mainloop, 1, NULL);
+        pa_mainloop_iterate(p_test_mainloop, 1, nullptr);
 
         if (!PA_CONTEXT_IS_GOOD(pa_context_get_state(p_test_context))) {
             logMessage(QLatin1String("PulseAudio probe complete."));
@@ -894,7 +894,7 @@ PulseSupport::PulseSupport()
 
     // Now we connect for real using a proper main loop that we can forget
     // all about processing.
-    s_mainloop = pa_glib_mainloop_new(NULL);
+    s_mainloop = pa_glib_mainloop_new(nullptr);
     Q_ASSERT(s_mainloop);
 
     connectToDaemon();
@@ -906,12 +906,12 @@ PulseSupport::~PulseSupport()
 #ifdef HAVE_PULSEAUDIO
     if (s_context) {
         pa_context_disconnect(s_context);
-        s_context = NULL;
+        s_context = nullptr;
     }
 
     if (s_mainloop) {
         pa_glib_mainloop_free(s_mainloop);
-        s_mainloop = NULL;
+        s_mainloop = nullptr;
     }
 #endif
 }
@@ -923,8 +923,8 @@ void PulseSupport::connectToDaemon()
     pa_mainloop_api *api = pa_glib_mainloop_get_api(s_mainloop);
 
     s_context = pa_context_new(api, "libphonon");
-    if (pa_context_connect(s_context, NULL, PA_CONTEXT_NOFAIL, 0) >= 0)
-        pa_context_set_state_callback(s_context, &context_state_callback, NULL);
+    if (pa_context_connect(s_context, nullptr, PA_CONTEXT_NOFAIL, nullptr) >= 0)
+        pa_context_set_state_callback(s_context, &context_state_callback, nullptr);
 #endif
 }
 
@@ -1081,11 +1081,11 @@ static void setDevicePriority(QString role, QStringList list)
     foreach (const QString &str, list) {
         devices[i++] = pa_xstrdup(str.toUtf8().constData());
     }
-    devices[list.size()] = NULL;
+    devices[list.size()] = nullptr;
 
 #if HAVE_PULSEAUDIO_DEVICE_MANAGER
     pa_operation *o;
-    if (!(o = pa_ext_device_manager_reorder_devices_for_role(s_context, role.toUtf8().constData(), (const char**)devices, NULL, NULL)))
+    if (!(o = pa_ext_device_manager_reorder_devices_for_role(s_context, role.toUtf8().constData(), (const char**)devices, nullptr, nullptr)))
         logMessage(QString::fromLatin1("pa_ext_device_manager_reorder_devices_for_role() failed"));
     else
         pa_operation_unref(o);
@@ -1165,7 +1165,7 @@ static PulseStream* register_stream(QMap<QString,PulseStream*> &map, QString str
     PulseStream *stream = new PulseStream(streamUuid, role);
     map[streamUuid] = stream;
 
-    // Setup envrionment...
+    // Setup environment...
     // These values are considered static, so we force property overrides for them.
     if (!Platform::applicationName().isEmpty())
         qputenv(QString("PULSE_PROP_OVERRIDE_%1").arg(PA_PROP_APPLICATION_NAME).toUtf8(),
@@ -1175,12 +1175,10 @@ static PulseStream* register_stream(QMap<QString,PulseStream*> &map, QString str
                 qApp->applicationVersion().toUtf8());
     if (!qApp->applicationName().isEmpty()) {
         QString icon;
-#if QT_VERSION >= QT_VERSION_CHECK(4, 7, 0)
         if (!qApp->windowIcon().isNull()){
             // Try to get the fromTheme() name of the QIcon.
             icon = qApp->windowIcon().name();
         }
-#endif
         if (icon.isEmpty()) {
             // If we failed to get a proper icon name, use the appname instead.
             icon = qApp->applicationName().toLower();
@@ -1244,7 +1242,7 @@ QHash<QString, QString> PulseSupport::streamProperties(QString streamUuid) const
     QHash<QString, QString> properties;
 
 #ifdef HAVE_PULSEAUDIO
-    PulseStream *stream = 0;
+    PulseStream *stream = nullptr;
 
     // Try to find the stream among the known output streams.
     if (!stream)
@@ -1278,8 +1276,8 @@ QHash<QString, QString> PulseSupport::streamProperties(QString streamUuid) const
 void PulseSupport::setupStreamEnvironment(QString streamUuid)
 {
     pDebug() << "Please note that your current Phonon backend is trying to force"
-                " stream dependent PulseAudio properties through envrionment variables."
-                " Slightly unprecise timing in doing so will cause the first"
+                " stream dependent PulseAudio properties through environment variables."
+                " Slightly imprecise timing in doing so will cause the first"
                 " of two subsequently started AudioOutputs to have disfunct volume"
                 " control. Also see https://bugs.kde.org/show_bug.cgi?id=321288";
 
@@ -1339,7 +1337,7 @@ bool PulseSupport::setOutputDevice(QString streamUuid, int device) {
 
         /// @todo Find a way to move the stream without saving it... We don't want to pollute the stream restore db.
         pa_operation* o;
-        if (!(o = pa_context_move_sink_input_by_index(s_context, pulse_stream_index, pulse_device_index, NULL, NULL))) {
+        if (!(o = pa_context_move_sink_input_by_index(s_context, pulse_stream_index, pulse_device_index, nullptr, nullptr))) {
             logMessage(QString::fromLatin1("pa_context_move_sink_input_by_index() failed"));
             return false;
         }
@@ -1374,7 +1372,7 @@ bool PulseSupport::setOutputVolume(QString streamUuid, qreal volume) {
 
         logMessage(QString::fromLatin1("Found PA index %1. Calling pa_context_set_sink_input_volume()").arg(stream->index()));
         pa_operation* o;
-        if (!(o = pa_context_set_sink_input_volume(s_context, stream->index(), &vol, NULL, NULL))) {
+        if (!(o = pa_context_set_sink_input_volume(s_context, stream->index(), &vol, nullptr, nullptr))) {
             logMessage(QString::fromLatin1("pa_context_set_sink_input_volume() failed"));
             return false;
         }
@@ -1402,7 +1400,7 @@ bool PulseSupport::setOutputMute(QString streamUuid, bool mute) {
 
         logMessage(QString::fromLatin1("Found PA index %1. Calling pa_context_set_sink_input_mute()").arg(stream->index()));
         pa_operation* o;
-        if (!(o = pa_context_set_sink_input_mute(s_context, stream->index(), (mute ? 1 : 0), NULL, NULL))) {
+        if (!(o = pa_context_set_sink_input_mute(s_context, stream->index(), (mute ? 1 : 0), nullptr, nullptr))) {
             logMessage(QString::fromLatin1("pa_context_set_sink_input_mute() failed"));
             return false;
         }
@@ -1439,7 +1437,7 @@ bool PulseSupport::setCaptureDevice(QString streamUuid, int device) {
 
         /// @todo Find a way to move the stream without saving it... We don't want to pollute the stream restore db.
         pa_operation* o;
-        if (!(o = pa_context_move_source_output_by_index(s_context, pulse_stream_index, pulse_device_index, NULL, NULL))) {
+        if (!(o = pa_context_move_source_output_by_index(s_context, pulse_stream_index, pulse_device_index, nullptr, nullptr))) {
             logMessage(QString::fromLatin1("pa_context_move_source_output_by_index() failed"));
             return false;
         }
