@@ -50,15 +50,15 @@ class SwiftSlider : public QSlider
 	Q_OBJECT
 public:
 	SwiftSlider(Qt::Orientation orientation, QWidget * parent);
-	~SwiftSlider();
+	~SwiftSlider() override;
 
 signals:
         void scrollStart();
         void scrollEnd();
 
 private:
-	void mousePressEvent(QMouseEvent *event);
-        void wheelEvent(QWheelEvent *event);
+    void mousePressEvent(QMouseEvent *event) override;
+        void wheelEvent(QWheelEvent *event) override;
 	inline int pick(const QPoint &pt) const;
         int pixelPosToRangeValue(int pos) const;
 
