@@ -44,6 +44,10 @@ VolumeSlider::VolumeSlider(QWidget *parent)
 #endif
 
     connect(&d->slider, SIGNAL(valueChanged(int)), SLOT(_k_sliderChanged(int)));
+    connect(&d->slider, SIGNAL(sliderPressed()), this, SLOT(_k_sliderPressed()));
+    connect(&d->slider, SIGNAL(sliderReleased()), this, SLOT(_k_sliderReleased()));
+    connect(&d->slider, SIGNAL(scrollStart()), this, SLOT(_k_sliderPressed()));
+    connect(&d->slider, SIGNAL(scrollEnd()), this, SLOT(_k_sliderReleased()));
     connect(&d->muteButton, SIGNAL(clicked()), SLOT(_k_buttonClicked()));
 
     setFocusProxy(&d->slider);
@@ -62,6 +66,10 @@ VolumeSlider::VolumeSlider(AudioOutput *output, QWidget *parent)
 #endif
 
     connect(&d->slider, SIGNAL(valueChanged(int)), SLOT(_k_sliderChanged(int)));
+    connect(&d->slider, SIGNAL(sliderPressed()), this, SLOT(_k_sliderPressed()));
+    connect(&d->slider, SIGNAL(sliderReleased()), this, SLOT(_k_sliderReleased()));
+    connect(&d->slider, SIGNAL(scrollStart()), this, SLOT(_k_sliderPressed()));
+    connect(&d->slider, SIGNAL(scrollEnd()), this, SLOT(_k_sliderReleased()));
     connect(&d->muteButton, SIGNAL(clicked()), SLOT(_k_buttonClicked()));
 
     if (output) {
@@ -142,7 +150,7 @@ void VolumeSlider::setAudioOutput(AudioOutput *output)
 {
     P_D(VolumeSlider);
     if (d->output) {
-        disconnect(d->output, 0, this, 0);
+        disconnect(d->output, nullptr, this, nullptr);
     }
     d->output = output;
     if (output) {
@@ -172,6 +180,19 @@ void VolumeSliderPrivate::_k_buttonClicked()
     }
 }
 
+void VolumeSliderPrivate::_k_sliderPressed()
+{
+    sliderPressed = true;
+}
+
+void VolumeSliderPrivate::_k_sliderReleased()
+{
+    sliderPressed = false;
+    if (output) {
+        _k_volumeChanged(output->volume());
+    }
+}
+
 void VolumeSliderPrivate::_k_mutedChanged(bool muted)
 {
 #ifndef QT_NO_TOOLTIP
@@ -218,6 +239,10 @@ void VolumeSliderPrivate::_k_sliderChanged(int value)
 
 void VolumeSliderPrivate::_k_volumeChanged(qreal value)
 {
+    if (sliderPressed) {
+        return;
+    }
+
     int newslidervalue = qRound(100 * value);
     if (!ignoreVolumeChangeAction && slider.value() != newslidervalue) {
         ignoreVolumeChangeObserve = true;
