@@ -23,7 +23,7 @@
 #ifndef VOLUMESLIDER_P_H
 #define VOLUMESLIDER_P_H
 
-#include <QtCore/QPointer>
+#include <QPointer>
 #include <QBoxLayout>
 #include <QIcon>
 #include <QLabel>
@@ -51,7 +51,7 @@ class VolumeSliderPrivate
             muteButton(parent),
             volumeIcon(Platform::icon(QLatin1String("player-volume"), parent->style())),
             mutedIcon(Platform::icon(QLatin1String("player-volume-muted"), parent->style())),
-            output(0),
+            output(nullptr),
             ignoreVolumeChangeAction(false),
             ignoreVolumeChangeObserve(true),
             sliderPressed(false)
@@ -62,7 +62,7 @@ class VolumeSliderPrivate
 
             muteButton.setIcon(volumeIcon);
             muteButton.setAutoRaise(true);
-            layout.setMargin(0);
+            layout.setContentsMargins(QMargins());
             layout.setSpacing(2);
             layout.addWidget(&muteButton, 0, Qt::AlignVCenter);
             layout.addWidget(&slider, 0, Qt::AlignVCenter);
