@@ -24,7 +24,9 @@
 int main(int argc, char **argv)
 {
     QApplication app(argc, argv);
+#if QT_VERSION < QT_VERSION_CHECK(6, 0, 0)
     app.setAttribute(Qt::AA_UseHighDpiPixmaps, true);
+#endif
     app.setApplicationName(QObject::tr("Phonon Settings"));
     app.setApplicationVersion(QString("1.0"));
     app.setOrganizationDomain(QString("kde.org"));
